==> fsx-1.93.0-sources.jar: software/amazon/awscdk/services/fsx/LustreFileSystemProps.java <==
package software.amazon.awscdk.services.fsx;

/**
 * (experimental) Properties specific to the Lustre version of the FSx file system.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.432Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.fsx.$Module.class, fqn = "@aws-cdk/aws-fsx.LustreFileSystemProps")
@software.amazon.jsii.Jsii.Proxy(LustreFileSystemProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface LustreFileSystemProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.fsx.FileSystemProps {

    /**
     * (experimental) Additional configuration for FSx specific to Lustre.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.fsx.LustreConfiguration getLustreConfiguration();

    /**
     * (experimental) The subnet that the file system will be accessible from.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.ISubnet getVpcSubnet();

    /**
     * @return a {@link Builder} of {@link LustreFileSystemProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LustreFileSystemProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<LustreFileSystemProps> {
        private software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration;
        private software.amazon.awscdk.services.ec2.ISubnet vpcSubnet;
        private java.lang.Number storageCapacityGiB;
        private software.amazon.awscdk.services.ec2.IVpc vpc;
        private java.lang.String backupId;
        private software.amazon.awscdk.services.kms.IKey kmsKey;
        private software.amazon.awscdk.core.RemovalPolicy removalPolicy;
        private software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup;

        /**
         * Sets the value of {@link LustreFileSystemProps#getLustreConfiguration}
         * @param lustreConfiguration Additional configuration for FSx specific to Lustre. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lustreConfiguration(software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration) {
            this.lustreConfiguration = lustreConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getVpcSubnet}
         * @param vpcSubnet The subnet that the file system will be accessible from. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder vpcSubnet(software.amazon.awscdk.services.ec2.ISubnet vpcSubnet) {
            this.vpcSubnet = vpcSubnet;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getStorageCapacityGiB}
         * @param storageCapacityGiB The storage capacity of the file system being created. This parameter is required.
         *                           For Windows file systems, valid values are 32 GiB to 65,536 GiB.
         *                           For SCRATCH_1 deployment types, valid values are 1,200, 2,400, 3,600, then continuing in increments of 3,600 GiB.
         *                           For SCRATCH_2 and PERSISTENT_1 types, valid values are 1,200, 2,400, then continuing in increments of 2,400 GiB.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder storageCapacityGiB(java.lang.Number storageCapacityGiB) {
            this.storageCapacityGiB = storageCapacityGiB;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getVpc}
         * @param vpc The VPC to launch the file system in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder vpc(software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.vpc = vpc;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getBackupId}
         * @param backupId The ID of the backup.
         *                 Specifies the backup to use if you're creating a file system from an existing backup.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder backupId(java.lang.String backupId) {
            this.backupId = backupId;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getKmsKey}
         * @param kmsKey The KMS key used for encryption to protect your data at rest.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder kmsKey(software.amazon.awscdk.services.kms.IKey kmsKey) {
            this.kmsKey = kmsKey;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getRemovalPolicy}
         * @param removalPolicy Policy to apply when the file system is removed from the stack.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder removalPolicy(software.amazon.awscdk.core.RemovalPolicy removalPolicy) {
            this.removalPolicy = removalPolicy;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getSecurityGroup}
         * @param securityGroup Security Group to assign to this file system.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder securityGroup(software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup) {
            this.securityGroup = securityGroup;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LustreFileSystemProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public LustreFileSystemProps build() {
            return new Jsii$Proxy(lustreConfiguration, vpcSubnet, storageCapacityGiB, vpc, backupId, kmsKey, removalPolicy, securityGroup);
        }
    }

    /**
     * An implementation for {@link LustreFileSystemProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LustreFileSystemProps {
        private final software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration;
        private final software.amazon.awscdk.services.ec2.ISubnet vpcSubnet;
        private final java.lang.Number storageCapacityGiB;
        private final software.amazon.awscdk.services.ec2.IVpc vpc;
        private final java.lang.String backupId;
        private final software.amazon.awscdk.services.kms.IKey kmsKey;
        private final software.amazon.awscdk.core.RemovalPolicy removalPolicy;
        private final software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.lustreConfiguration = software.amazon.jsii.Kernel.get(this, "lustreConfiguration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.fsx.LustreConfiguration.class));
            this.vpcSubnet = software.amazon.jsii.Kernel.get(this, "vpcSubnet", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.ISubnet.class));
            this.storageCapacityGiB = software.amazon.jsii.Kernel.get(this, "storageCapacityGiB", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.vpc = software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
            this.backupId = software.amazon.jsii.Kernel.get(this, "backupId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.kmsKey = software.amazon.jsii.Kernel.get(this, "kmsKey", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kms.IKey.class));
            this.removalPolicy = software.amazon.jsii.Kernel.get(this, "removalPolicy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.RemovalPolicy.class));
            this.securityGroup = software.amazon.jsii.Kernel.get(this, "securityGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.ISecurityGroup.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration, final software.amazon.awscdk.services.ec2.ISubnet vpcSubnet, final java.lang.Number storageCapacityGiB, final software.amazon.awscdk.services.ec2.IVpc vpc, final java.lang.String backupId, final software.amazon.awscdk.services.kms.IKey kmsKey, final software.amazon.awscdk.core.RemovalPolicy removalPolicy, final software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.lustreConfiguration = java.util.Objects.requireNonNull(lustreConfiguration, "lustreConfiguration is required");
            this.vpcSubnet = java.util.Objects.requireNonNull(vpcSubnet, "vpcSubnet is required");
            this.storageCapacityGiB = java.util.Objects.requireNonNull(storageCapacityGiB, "storageCapacityGiB is required");
            this.vpc = java.util.Objects.requireNonNull(vpc, "vpc is required");
            this.backupId = backupId;
            this.kmsKey = kmsKey;
            this.removalPolicy = removalPolicy;
            this.securityGroup = securityGroup;
        }

        @Override
        public final software.amazon.awscdk.services.fsx.LustreConfiguration getLustreConfiguration() {
            return this.lustreConfiguration;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.ISubnet getVpcSubnet() {
            return this.vpcSubnet;
        }

        @Override
        public final java.lang.Number getStorageCapacityGiB() {
            return this.storageCapacityGiB;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.vpc;
        }

        @Override
        public final java.lang.String getBackupId() {
            return this.backupId;
        }

        @Override
        public final software.amazon.awscdk.services.kms.IKey getKmsKey() {
            return this.kmsKey;
        }

        @Override
        public final software.amazon.awscdk.core.RemovalPolicy getRemovalPolicy() {
            return this.removalPolicy;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.ISecurityGroup getSecurityGroup() {
            return this.securityGroup;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("lustreConfiguration", om.valueToTree(this.getLustreConfiguration()));
            data.set("vpcSubnet", om.valueToTree(this.getVpcSubnet()));
            data.set("storageCapacityGiB", om.valueToTree(this.getStorageCapacityGiB()));
            data.set("vpc", om.valueToTree(this.getVpc()));
            if (this.getBackupId() != null) {
                data.set("backupId", om.valueToTree(this.getBackupId()));
            }
            if (this.getKmsKey() != null) {
                data.set("kmsKey", om.valueToTree(this.getKmsKey()));
            }
            if (this.getRemovalPolicy() != null) {
                data.set("removalPolicy", om.valueToTree(this.getRemovalPolicy()));
            }
            if (this.getSecurityGroup() != null) {
                data.set("securityGroup", om.valueToTree(this.getSecurityGroup()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-fsx.LustreFileSystemProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LustreFileSystemProps.Jsii$Proxy that = (LustreFileSystemProps.Jsii$Proxy) o;

            if (!lustreConfiguration.equals(that.lustreConfiguration)) return false;
            if (!vpcSubnet.equals(that.vpcSubnet)) return false;
            if (!storageCapacityGiB.equals(that.storageCapacityGiB)) return false;
            if (!vpc.equals(that.vpc)) return false;
            if (this.backupId != null ? !this.backupId.equals(that.backupId) : that.backupId != null) return false;
            if (this.kmsKey != null ? !this.kmsKey.equals(that.kmsKey) : that.kmsKey != null) return false;
            if (this.removalPolicy != null ? !this.removalPolicy.equals(that.removalPolicy) : that.removalPolicy != null) return false;
            return this.securityGroup != null ? this.securityGroup.equals(that.securityGroup) : that.securityGroup == null;
        }

        @Override
        public final int hashCode() {
            int result = this.lustreConfiguration.hashCode();
            result = 31 * result + (this.vpcSubnet.hashCode());
            result = 31 * result + (this.storageCapacityGiB.hashCode());
            result = 31 * result + (this.vpc.hashCode());
            result = 31 * result + (this.backupId != null ? this.backupId.hashCode() : 0);
            result = 31 * result + (this.kmsKey != null ? this.kmsKey.hashCode() : 0);
            result = 31 * result + (this.removalPolicy != null ? this.removalPolicy.hashCode() : 0);
            result = 31 * result + (this.securityGroup != null ? this.securityGroup.hashCode() : 0);
            return result;
        }
    }
}

==> fsx-1.182.0-sources.jar: software/amazon/awscdk/services/fsx/LustreFileSystemProps.java <==
package software.amazon.awscdk.services.fsx;

/**
 * Properties specific to the Lustre version of the FSx file system.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * LustreFileSystem fileSystem = LustreFileSystem.Builder.create(this, "FsxLustreFileSystem")
 *         .lustreConfiguration(LustreConfiguration.builder().deploymentType(LustreDeploymentType.SCRATCH_2).build())
 *         .storageCapacityGiB(1200)
 *         .vpc(vpc)
 *         .vpcSubnet(vpc.getPrivateSubnets()[0])
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:41.671Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.fsx.$Module.class, fqn = "@aws-cdk/aws-fsx.LustreFileSystemProps")
@software.amazon.jsii.Jsii.Proxy(LustreFileSystemProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LustreFileSystemProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.fsx.FileSystemProps {

    /**
     * Additional configuration for FSx specific to Lustre.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.fsx.LustreConfiguration getLustreConfiguration();

    /**
     * The subnet that the file system will be accessible from.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.ISubnet getVpcSubnet();

    /**
     * @return a {@link Builder} of {@link LustreFileSystemProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LustreFileSystemProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LustreFileSystemProps> {
        software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration;
        software.amazon.awscdk.services.ec2.ISubnet vpcSubnet;
        java.lang.Number storageCapacityGiB;
        software.amazon.awscdk.services.ec2.IVpc vpc;
        java.lang.String backupId;
        software.amazon.awscdk.services.kms.IKey kmsKey;
        software.amazon.awscdk.core.RemovalPolicy removalPolicy;
        software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup;

        /**
         * Sets the value of {@link LustreFileSystemProps#getLustreConfiguration}
         * @param lustreConfiguration Additional configuration for FSx specific to Lustre. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder lustreConfiguration(software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration) {
            this.lustreConfiguration = lustreConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getVpcSubnet}
         * @param vpcSubnet The subnet that the file system will be accessible from. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpcSubnet(software.amazon.awscdk.services.ec2.ISubnet vpcSubnet) {
            this.vpcSubnet = vpcSubnet;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getStorageCapacityGiB}
         * @param storageCapacityGiB The storage capacity of the file system being created. This parameter is required.
         *                           For Windows file systems, valid values are 32 GiB to 65,536 GiB.
         *                           For SCRATCH_1 deployment types, valid values are 1,200, 2,400, 3,600, then continuing in increments of 3,600 GiB.
         *                           For SCRATCH_2 and PERSISTENT_1 types, valid values are 1,200, 2,400, then continuing in increments of 2,400 GiB.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder storageCapacityGiB(java.lang.Number storageCapacityGiB) {
            this.storageCapacityGiB = storageCapacityGiB;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getVpc}
         * @param vpc The VPC to launch the file system in. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.vpc = vpc;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getBackupId}
         * @param backupId The ID of the backup.
         *                 Specifies the backup to use if you're creating a file system from an existing backup.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder backupId(java.lang.String backupId) {
            this.backupId = backupId;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getKmsKey}
         * @param kmsKey The KMS key used for encryption to protect your data at rest.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder kmsKey(software.amazon.awscdk.services.kms.IKey kmsKey) {
            this.kmsKey = kmsKey;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getRemovalPolicy}
         * @param removalPolicy Policy to apply when the file system is removed from the stack.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder removalPolicy(software.amazon.awscdk.core.RemovalPolicy removalPolicy) {
            this.removalPolicy = removalPolicy;
            return this;
        }

        /**
         * Sets the value of {@link LustreFileSystemProps#getSecurityGroup}
         * @param securityGroup Security Group to assign to this file system.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder securityGroup(software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup) {
            this.securityGroup = securityGroup;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LustreFileSystemProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LustreFileSystemProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LustreFileSystemProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LustreFileSystemProps {
        private final software.amazon.awscdk.services.fsx.LustreConfiguration lustreConfiguration;
        private final software.amazon.awscdk.services.ec2.ISubnet vpcSubnet;
        private final java.lang.Number storageCapacityGiB;
        private final software.amazon.awscdk.services.ec2.IVpc vpc;
        private final java.lang.String backupId;
        private final software.amazon.awscdk.services.kms.IKey kmsKey;
        private final software.amazon.awscdk.core.RemovalPolicy removalPolicy;
        private final software.amazon.awscdk.services.ec2.ISecurityGroup securityGroup;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.lustreConfiguration = software.amazon.jsii.Kernel.get(this, "lustreConfiguration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.fsx.LustreConfiguration.class));
            this.vpcSubnet = software.amazon.jsii.Kernel.get(this, "vpcSubnet", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.ISubnet.class));
            this.storageCapacityGiB = software.amazon.jsii.Kernel.get(this, "storageCapacityGiB", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.vpc = software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
            this.backupId = software.amazon.jsii.Kernel.get(this, "backupId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.kmsKey = software.amazon.jsii.Kernel.get(this, "kmsKey", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kms.IKey.class));
            this.removalPolicy = software.amazon.jsii.Kernel.get(this, "removalPolicy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.RemovalPolicy.class));
            this.securityGroup = software.amazon.jsii.Kernel.get(this, "securityGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.ISecurityGroup.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.lustreConfiguration = java.util.Objects.requireNonNull(builder.lustreConfiguration, "lustreConfiguration is required");
            this.vpcSubnet = java.util.Objects.requireNonNull(builder.vpcSubnet, "vpcSubnet is required");
            this.storageCapacityGiB = java.util.Objects.requireNonNull(builder.storageCapacityGiB, "storageCapacityGiB is required");
            this.vpc = java.util.Objects.requireNonNull(builder.vpc, "vpc is required");
            this.backupId = builder.backupId;
            this.kmsKey = builder.kmsKey;
            this.removalPolicy = builder.removalPolicy;
            this.securityGroup = builder.securityGroup;
        }

        @Override
        public final software.amazon.awscdk.services.fsx.LustreConfiguration getLustreConfiguration() {
            return this.lustreConfiguration;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.ISubnet getVpcSubnet() {
            return this.vpcSubnet;
        }

        @Override
        public final java.lang.Number getStorageCapacityGiB() {
            return this.storageCapacityGiB;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.vpc;
        }

        @Override
        public final java.lang.String getBackupId() {
            return this.backupId;
        }

        @Override
        public final software.amazon.awscdk.services.kms.IKey getKmsKey() {
            return this.kmsKey;
        }

        @Override
        public final software.amazon.awscdk.core.RemovalPolicy getRemovalPolicy() {
            return this.removalPolicy;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.ISecurityGroup getSecurityGroup() {
            return this.securityGroup;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("lustreConfiguration", om.valueToTree(this.getLustreConfiguration()));
            data.set("vpcSubnet", om.valueToTree(this.getVpcSubnet()));
            data.set("storageCapacityGiB", om.valueToTree(this.getStorageCapacityGiB()));
            data.set("vpc", om.valueToTree(this.getVpc()));
            if (this.getBackupId() != null) {
                data.set("backupId", om.valueToTree(this.getBackupId()));
            }
            if (this.getKmsKey() != null) {
                data.set("kmsKey", om.valueToTree(this.getKmsKey()));
            }
            if (this.getRemovalPolicy() != null) {
                data.set("removalPolicy", om.valueToTree(this.getRemovalPolicy()));
            }
            if (this.getSecurityGroup() != null) {
                data.set("securityGroup", om.valueToTree(this.getSecurityGroup()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-fsx.LustreFileSystemProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LustreFileSystemProps.Jsii$Proxy that = (LustreFileSystemProps.Jsii$Proxy) o;

            if (!lustreConfiguration.equals(that.lustreConfiguration)) return false;
            if (!vpcSubnet.equals(that.vpcSubnet)) return false;
            if (!storageCapacityGiB.equals(that.storageCapacityGiB)) return false;
            if (!vpc.equals(that.vpc)) return false;
            if (this.backupId != null ? !this.backupId.equals(that.backupId) : that.backupId != null) return false;
            if (this.kmsKey != null ? !this.kmsKey.equals(that.kmsKey) : that.kmsKey != null) return false;
            if (this.removalPolicy != null ? !this.removalPolicy.equals(that.removalPolicy) : that.removalPolicy != null) return false;
            return this.securityGroup != null ? this.securityGroup.equals(that.securityGroup) : that.securityGroup == null;
        }

        @Override
        public final int hashCode() {
            int result = this.lustreConfiguration.hashCode();
            result = 31 * result + (this.vpcSubnet.hashCode());
            result = 31 * result + (this.storageCapacityGiB.hashCode());
            result = 31 * result + (this.vpc.hashCode());
            result = 31 * result + (this.backupId != null ? this.backupId.hashCode() : 0);
            result = 31 * result + (this.kmsKey != null ? this.kmsKey.hashCode() : 0);
            result = 31 * result + (this.removalPolicy != null ? this.removalPolicy.hashCode() : 0);
            result = 31 * result + (this.securityGroup != null ? this.securityGroup.hashCode() : 0);
            return result;
        }
    }
}
